@@ -28,7 +28,11 @@ socket_urls = {
         'trades': "wss://dataservices.btgpactualsolutions.com/stream/v2/marketdata/trade/options/delayed",
     },
     'indices_realtime': "wss://dataservices.btgpactualsolutions.com/stream/v2/marketdata/indices",
-    'indices_delayed': "wss://dataservices.btgpactualsolutions.com/stream/v2/marketdata/indices/delayed"
+    'indices_delayed': "wss://dataservices.btgpactualsolutions.com/stream/v2/marketdata/indices/delayed",
+    
+    'hfn_realtime': {
+        'brazil': "wss://dataservices.btgpactualsolutions.com/stream/v2/hfn/brazil",
+    },
 }
 
 keys_socket = list(socket_urls.keys())
@@ -45,4 +49,5 @@ MAX_WS_RECONNECT_RETRIES = 5
 
 ### Rest
 url_apis = "https://dataservices.btgpactualsolutions.com/api/v2"
-url_api_v1 = "https://dataservices.btgpactualsolutions.com/api/v1"
\ No newline at end of file
+url_api_v1 = "https://dataservices.btgpactualsolutions.com/api/v1"
+url_apis_v3 = "https://dataservices.btgpactualsolutions.com/api/v3"
\ No newline at end of file
